# OrderCategory

Category of the order to indicate a product sale or return. Default value is `NewSales`. 

## Enum

* `NEWSALES` (value: `'NewSales'`)

* `RETURN` (value: `'Return'`)

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


